=======
specsim
=======

Quick simulations of fiber spectrograph response.

Citation
--------

|DOI|

Please cite as:

David Kirkby, *et al.*. (2026).
desihub/specsim: Title (v1.0.0). Zenodo. https://doi.org/10.5281/zenodo.xxxxxxxx

See also the file ``CITATION.cff``.

Status reports for developers
-----------------------------

|Astropy| |PyPI| |License| |Coveralls Status| |Documentation Status|

.. |DOI| image:: https://zenodo.org/badge/41930235.svg
   :target: https://zenodo.org/badge/latestdoi/41930235
   :alt: DOI: zenodo.41930235

.. |Astropy| image:: http://img.shields.io/badge/powered%20by-AstroPy-orange.svg?style=flat
    :target: http://www.astropy.org
    :alt: Powered by Astropy Badge

.. |License| image:: https://img.shields.io/pypi/l/specsim.svg
    :target: https://pypi.org/project/specsim/
    :alt: BSD License

.. |Actions Status| image:: https://github.com/desihub/specsim/workflows/CI/badge.svg
    :target: https://github.com/desihub/specsim/actions
    :alt: GitHub Actions CI Status

.. |Coveralls Status| image:: https://coveralls.io/repos/desihub/specsim/badge.svg?branch=main
    :target: https://coveralls.io/github/desihub/specsim?branch=main
    :alt: Test Coverage Status

.. |Documentation Status| image:: https://readthedocs.org/projects/specsim/badge/?version=latest
    :target: https://specsim.readthedocs.io/en/latest/
    :alt: Documentation Status

.. |PyPI| image:: https://img.shields.io/pypi/v/specsim.svg
    :target: https://pypi.org/pypi/specsim
    :alt: Distribution Status

Contributing to the specsim Package
-----------------------------------

This package is maintained and developed under the GitHub
`desihub organization`_ but, unlike most packages
there, is designed to be a general purpose tool that can be configured to
simulate any fiber spectrograph.  As such, it uses a package template
based on `Astropy Affiliated Packages`_
rather than the `DESI software template`_.

.. _`desihub organization`: https://github.com/desihub
.. _`Astropy Affiliated Packages`: https://www.astropy.org/affiliated/index.html
.. _`DESI software template`: https://github.com/desihub/desitemplate

License
-------

specsim is free software licensed under a 3-clause BSD-style license. For details see
the ``LICENSE.rst`` file.

